@@ -91,6 +91,8 @@
 // binding values
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
+APPKIT_EXPORT BOOL NSIsControllerMarker(id object);
+
 // Keys in dictionary returned by infoForBinding
 APPKIT_EXPORT NSString *NSObservedObjectKey;
 APPKIT_EXPORT NSString *NSObservedKeyPathKey;
@@ -103,12 +105,22 @@ APPKIT_EXPORT id NSNotApplicableMarker;
 
 // Binding name constants
 APPKIT_EXPORT NSString *NSAlignmentBinding;
+APPKIT_EXPORT NSString *NSContentArrayBinding;
+APPKIT_EXPORT NSString *NSContentBinding;
 APPKIT_EXPORT NSString *NSContentObjectBinding;
+APPKIT_EXPORT NSString *NSContentValuesBinding;
 APPKIT_EXPORT NSString *NSEditableBinding;
 APPKIT_EXPORT NSString *NSEnabledBinding;
 APPKIT_EXPORT NSString *NSFontBinding;
+APPKIT_EXPORT NSString *NSFontNameBinding;
+APPKIT_EXPORT NSString *NSFontSizeBinding;
 APPKIT_EXPORT NSString *NSHiddenBinding;
 APPKIT_EXPORT NSString *NSSelectedIndexBinding;
+APPKIT_EXPORT NSString *NSSelectedObjectBinding;
+APPKIT_EXPORT NSString *NSSelectedTagBinding;
+APPKIT_EXPORT NSString *NSSelectedValueBinding;
+APPKIT_EXPORT NSString *NSSelectionIndexesBinding;
+APPKIT_EXPORT NSString *NSSortDescriptorsBinding;
 APPKIT_EXPORT NSString *NSTextColorBinding;
 APPKIT_EXPORT NSString *NSTitleBinding;
 APPKIT_EXPORT NSString *NSToolTipBinding;
