@@ -14,7 +14,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 3 of the License, or (at your option) any later version.
+   version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,8 +33,13 @@
 #import <GNUstepBase/GSVersionMacros.h>
 
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
+/* IBOutlet and IBAction are now built-in macros in recent Clang */
+#if !defined(IBOutlet)
 #define IBOutlet
+#endif
+#if !defined(IBAction)
 #define IBAction void
 #endif
+#endif
 
 #endif
